body {
  background-color: #000000;
  color: #ff0000;
  font-weight: normal;
  font-style: normal;
}

.keyword {
  color: #ffffff;
  font-weight: bold;
  font-style: normal;
}

.type {
  color: #F35E1E;
  font-weight: bold;
  font-style: normal;
}

.string {
  color: #bb00ff;
  font-weight: normal;
  font-style: normal;
}

.specialchar {
  color: #ffffff;
  font-weight: normal;
  font-style: normal;
}

.comment {
  color: #ababab;
  font-weight: normal;
  font-style: italic;
}

.number {
  color: #bb00ff;
  font-weight: normal;
  font-style: normal;
}

.preproc {
  color: #ababab;
  font-weight: normal;
  font-style: normal;
}

.symbol {
  color: #F3E651;
  font-weight: normal;
  font-style: normal;
}

.function {
  color: #7bc710;
  font-weight: normal;
  font-style: normal;
}

.cbracket {
  color: #F3E651;
  font-weight: normal;
  font-style: normal;
}

