body {
  background-color: #ffffff;
  color: #000000;
  font-weight: normal;
  font-style: normal;
}

.keyword {
  color: #0000b3;
  font-weight: normal;
  font-style: normal;
}

.type {
  color: #4c73a6;
  font-weight: normal;
  font-style: normal;
}

.string {
  color: #666666;
  font-weight: normal;
  font-style: normal;
}

.specialchar {
  color: #666666;
  font-weight: normal;
  font-style: normal;
}

.comment {
  color: #b30000;
  font-weight: normal;
  font-style: normal;
}

.number {
  color: #000000;
  font-weight: normal;
  font-style: normal;
}

.preproc {
  color: #0000b3;
  font-weight: normal;
  font-style: normal;
}

.function {
  color: #000000;
  font-weight: normal;
  font-style: normal;
}

