body {
  background-color: #000000;
  color: #ffffff;
  font-weight: normal;
  font-style: normal;
}

.keyword {
  color: #c0c000;
  font-weight: bold;
  font-style: normal;
}

.type {
  color: #00c000;
  font-weight: bold;
  font-style: normal;
}

.string {
  color: #00ffff;
  font-weight: normal;
  font-style: normal;
}

.specialchar {
  color: #0000ff;
  font-weight: normal;
  font-style: normal;
}

.comment {
  color: #808080;
  font-weight: normal;
  font-style: normal;
}

.number {
  color: #00ffff;
  font-weight: normal;
  font-style: normal;
}

.preproc {
  color: #00ff00;
  font-weight: normal;
  font-style: normal;
}

.symbol {
  color: #ff0000;
  font-weight: normal;
  font-style: normal;
}

.function {
  color: #ff22b9;
  font-weight: normal;
  font-style: normal;
}

.cbracket {
  color: #ff0000;
  font-weight: normal;
  font-style: normal;
}

